@@ -4,7 +4,7 @@
  * For information on usage and redistribution, and for a DISCLAIMER OF ALL
  * WARRANTIES, see the file, "LICENSE.txt," in this distribution.  */
 
-/* Porres 2016-2018 for versions 0.3 onward:
+/* Porres 2016 for versions 0.3 onward:
  This is the cyclone library containing 12 non alphanumeric objects.
  Originally, the externals in cyclone used to come in a library called
  "cyclone", which included these 12 objects plus the "hammer" and "sickle"
@@ -629,21 +629,21 @@ t_class *cyclone_class;
 static int printed;
 
 static int min_major = 0;
-static int min_minor = 54;
+static int min_minor = 55;
 static int min_bugfix = 0;
 
 static int cyclone_major = 0;
-static int cyclone_minor = 8;
-static int cyclone_bugfix = 0;
+static int cyclone_minor = 9;
+static int cyclone_bugfix = 2;
 
 void print_cyclone(t_cyclone *x){
     int major = 0, minor = 0, bugfix = 0;
     sys_getversion(&major, &minor, &bugfix);
     post("");
     post("--------------------------------------------------------------------");
-    post(":: Cyclone %d.%d-%d; Released October 22nd 2023", cyclone_major, cyclone_minor, cyclone_bugfix);
+    post(":: Cyclone %d.%d-%d; Released March 14th 2025", cyclone_major, cyclone_minor, cyclone_bugfix);
     post(":: License: BSD-3-Clause (aka Revised BSD License)");
-    post(":: Copyright © 2003-2021 - Krzysztof Czaja, Hans-Christoph Steiner,");
+    post(":: Copyright © 2003-2025 - Krzysztof Czaja, Hans-Christoph Steiner,");
     post(":: Fred Jan Kraan, Alexandre Porres, Derek Kwan, Matt Barber\n\:: and others.");
     post(":: -----------------------------------------------------------------");
     if((major > min_major)
@@ -665,6 +665,10 @@ void print_cyclone(t_cyclone *x){
     post(":: you need to add 'cyclone' to the \"preferences=>path\"");
     post(":: or use [declare -path cyclone] (this guarantees search priority)");
     post("--------------------------------------------------------------------");
+    post("-------------------------------------------------------------------");
+    post("- NOTE: Loading this binary did install an object browser");
+    post("plugin for Cyclone objects when right clicking on a canvas.");
+    post("-------------------------------------------------------------------");
     post("");
 }
 
@@ -852,6 +856,10 @@ CYCLONE_API void cyclone_setup(void)
     class_addbang(plusequals_class, plusequals_bang);
     class_addmethod(plusequals_class, (t_method)plusequals_set, gensym("set"), A_FLOAT, 0);
     class_sethelpsymbol(plusequals_class, gensym("plusequals~"));
+    
+    char plugin[MAXPDSTRING];
+    sprintf(plugin, "%s/browser-cyclone.tcl", cyclone_class->c_externdir->s_name);
+    pdgui_vmess("load_plugin_script", "s", plugin);
 
 #if CYCLONE_SINGLE_LIBRARY
     setup_single_lib();
